@@ -935,14 +935,6 @@ on_dock_bottom_radiobutton_toggled (GtkToggleButton *button,
 		gok_data_set_dock_type (GOK_DOCK_BOTTOM);
 }
 
-void
-on_aux_keyboard_dir_entry_changed (GtkEntry *entry,
-				   gpointer user_data)
-{
-	gok_data_set_aux_keyboard_directory (gtk_entry_get_text (entry));
-}
-
-
 void
 on_xkb_compose_keyboard_radiobutton_toggled (GtkToggleButton *button, 
 					     gpointer user_data)
@@ -975,14 +967,6 @@ on_file_compose_keyboard_radiobutton_toggled (GtkToggleButton *button,
 		gok_data_set_compose_keyboard_type (GOK_COMPOSE_CUSTOM);
 }
 
-void
-on_compose_keyboard_file_entry_changed (GtkEditable *editable, 
-					gpointer user_data)
-{
-	gok_data_set_custom_compose_filename (
-		gtk_editable_get_chars (editable, 0, -1));
-}
-
 void
 on_core_pointer_button_toggled         (GtkToggleButton *togglebutton,
                                         gpointer         user_data)
@@ -991,7 +975,6 @@ on_core_pointer_button_toggled         (GtkToggleButton *togglebutton,
 		gtk_toggle_button_get_active (togglebutton));
 }
 
-
 void
 on_xinput_device_button_toggled        (GtkToggleButton *togglebutton,
                                         gpointer         user_data)
